@@ -1,6 +1,6 @@
 import json
 import logging
-from typing import Dict, List, Union
+from typing import Dict, List, Optional, Union
 
 from google.oauth2 import service_account
 from google.oauth2.credentials import Credentials
@@ -9,7 +9,6 @@ from googleapiclient.errors import HttpError
 
 from arcane.core.exceptions import BadRequestError
 
-
 class GoogleAnalyticsAccountLostAccessException(Exception):
     """ Raised when we cannot access to an account """
     pass
@@ -19,6 +18,13 @@ class GoogleAnalyticsServiceDownException(Exception):
     pass
 
 
+def get_exception_message(view_id: str, access_token: Optional[str] = None) -> str:
+    if access_token:
+        return F"We cannot access your view with the id: {view_id}. Are you sure you have access and entered correct ID?"
+    else:
+        return F"We cannot access your view with the id: {view_id} from the Arcane account. Are you sure you granted access and gave the correct ID?"
+
+
 def get_metrics_from_view(ga_view: str,
                           adscale_key: str,
                           date_ranges: Dict=None,
@@ -58,9 +64,9 @@ def get_metrics_from_view(ga_view: str,
 
 def get_view_name(
     view_id: str,
-    adscale_key: str = None,
-    access_token: str = None
-) -> Union[str, None]:
+    adscale_key: Optional[str] = None,
+    access_token: Optional[str] = None
+) -> Optional[str]:
     """
         From an view id check if user has access to it and return the name of view
 
@@ -79,16 +85,17 @@ def get_view_name(
     service = build('analytics', 'v3', credentials=credentials)
     if 'ga:' in view_id:
         view_id = view_id.replace('ga:', '')
+
     try:
         views = service.management().profiles().list(accountId='~all', webPropertyId='~all').execute()
     except HttpError as err:
         if err.resp.status >= 400 and err.resp.status < 500:
-            raise GoogleAnalyticsAccountLostAccessException(F"We cannot access your view with the id: {view_id}. Are you sure you granted access and entered correct ID?")
+            raise GoogleAnalyticsAccountLostAccessException(get_exception_message(view_id, access_token))
         else:
             raise GoogleAnalyticsServiceDownException(f"The Google Analytics API does not respond. Thus, we cannot check if we can access your Google Analytics account with the id: {view_id}. Please try later" )
 
     if view_id not in [view.get('id') for view in views.get('items', [])]:
-        raise GoogleAnalyticsAccountLostAccessException(F"We cannot access your view with the id: {view_id}. Are you sure you granted access and entered correct ID?")
+        raise GoogleAnalyticsAccountLostAccessException(get_exception_message(view_id, access_token))
 
     for view in views.get('items', []):
         if view.get('id') == view_id:
